#!/usr/bin/perl

use strict;
use warnings;

use lib ('../');
use FindBin;

use Test::More tests => 6;

use Logaholic::IO::File;

my $testdir      = $FindBin::Bin . '/data';
my $test_file    = $testdir . '/domlog';
my $test_file_gz = $testdir . '/domlog_gzipped.gz';

#note('');
{
    my $expected_line =
'66.249.66.24 - - [20/Jul/2012:04:55:49 +0200] "GET /cdshop/advanced_search_result.php?keywords=uw&manufacturers_id=28&sort=1a&language=nl&osCsid=0cbra1hfv7i5lalm4oovh4qt21 HTTP/1.1" 200 31073 "-" "Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)" "-"'
      . "\n";
    my $obj = Logaholic::IO::File->new( $test_file, 'r' );
    $obj->open();
    my $line = $obj->readline();
    is( $line, $expected_line, 'can readline from uncompressed file' );
    $obj->close();
}

{
    my $expected_line =
'24 - - [20/Jul/2012:04:55:49 +0200] "GET /cdshop/advanced_search_result.php?keywords=uw&manufacturers_id=28&sort=1a&language=nl&osCsid=0cbra1hfv7i5lalm4oovh4qt21 HTTP/1.1" 200 31073 "-" "Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)" "-"'
      . "\n";
    my $obj = Logaholic::IO::File->new( $test_file, 'r' );
    $obj->open();
    $obj->seek(10);

    my $line = $obj->readline();
    is( $line, $expected_line, 'can seek forward in uncompressed file' );

    my $position = $obj->tell();
    is( $position, 275, 'can tell on uncompressed file' );

    $obj->close();
}

{
    my $expected_line =
'66.249.66.24 - - [20/Jul/2012:04:55:49 +0200] "GET /cdshop/advanced_search_result.php?keywords=uw&manufacturers_id=28&sort=1a&language=nl&osCsid=0cbra1hfv7i5lalm4oovh4qt21 HTTP/1.1" 200 31073 "-" "Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)" "-"'
      . "\n";
    my $obj = Logaholic::IO::File->new( $test_file_gz, 'r' );
    $obj->open();
    my $line = $obj->readline();
    is( $line, $expected_line, 'can readline from compressed file' );
    $obj->close();
}

{
    my $expected_line =
'24 - - [20/Jul/2012:04:55:49 +0200] "GET /cdshop/advanced_search_result.php?keywords=uw&manufacturers_id=28&sort=1a&language=nl&osCsid=0cbra1hfv7i5lalm4oovh4qt21 HTTP/1.1" 200 31073 "-" "Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)" "-"'
      . "\n";
    my $obj = Logaholic::IO::File->new( $test_file_gz, 'r' );
    $obj->open();
    $obj->seek(10);

    my $line = $obj->readline();
    is( $line, $expected_line, 'can seek forward in compressed file' );

    my $position = $obj->tell();
    is( $position, 275, 'can tell on compressed file' );

    $obj->close();
}
