<?php
/* Logaholic Web Analytics software             Copyright(c) 2005-2011 Logaholic B.V.
 *                                                               All rights Reserved.
 * This code is subject to the Logaholic license. Unauthorized copying is prohibited.
 * support@logaholic.com                         http://www.logaholic.com/License.txt
*/ 
/**
* @desc This report displays a overview of your performance trends
*/
$reports["_PERFORMANCE_TRENDS"] = Array(
	"ClassName" => "PerformanceTrends", 
	"Category" => "_PERFORMANCE", 
	"icon" => "images/icons/32x32/performancetrends.png",
	"Options" => "daterangeField,profileselector,trafficsource,displaymode,limit",
	"Filename" => "performance_trends",
	"Distribution" => "Standard",
	"Order" => 1,
	"ReportVersion" => 1.0,
	"MinimumVersion" => 3.0,
	"EmailAlerts" => false,
	"Update" => false
);

include_once "overall_performance.php";

class PerformanceTrends extends OverallPerformance {

	function Settings() {
		$this->DefaultDisplay = "linechart";
		$this->DisplayModes = "table,linechart";
		$this->help = "";
		$this->displayReportButtons = false;
		$this->actionmenu_type = 'page';
		$this->label = _OVERALL_PERFORMANCE;
		
		if(empty($this->conversion_mode)) {
			$this->conversion_mode = _CONVERSION_RATE;
		}
	}
	
	function getDataFromFiles($files) {
		$data = array();
		$path = "{$this->profile->datamanagerDir}{$this->profile->profilename}/reports/";
			
		foreach($files as $file) {
			$filetime = str_replace($path,'',$file);
			$t = explode(".",$filetime);
			$data[$t[1]] = $this->getDataFromFile($file);
		}
		return $data;
	}
	# returns the array of files we want to open
	function dataFiles($from,$to) {
		global $get_constant;
		$files = array();
		$time = $from;
		while($time <= $to) {
			$path = "{$this->profile->datamanagerDir}{$this->profile->profilename}/reports/".date("Y",$time)."/{$get_constant[$this->label]}";
			$dist = $to - $time;
			$daterange = date("Ymd",$time);
			$files[] = "$path/{$get_constant[$this->label]}.{$daterange}{$this->fileNameExpension}.gz";
			$time=$time+86400;
		}		
		return $files;		
	}
	
	function getReportData(){
		global $db, $get_constant;
		
		$this->createDataFiles($this->from,$this->to);	
		$data = $this->getDataFromFiles($this->dataFiles($this->from,$this->to));
		$newdata = array();	
		
		$i = 0;
		foreach($data as $k => $v){
			$date = mktime(0,0,0,substr($k,4,-2),substr($k,6,7),substr($k,0,4));
			$date = date("D, m/d/Y",$date);
			if(empty($v)) { continue; }
			foreach($v as $ck => $cv){
				$url = $cv[0];
				$newdata[$i][0] = $date; # Date
				$newdata[$i][1] = $cv[0]; # Url
				if($this->conversion_mode == _CONVERTED_VISITORS) {
					$newdata[$i][2] = $cv[1]; # Requests
					$newdata[$i][3] = $cv[2]; # Converted Visitors
				} else {
					$newdata[$i][2] = $cv[2]; # Converted Visitors
					$newdata[$i][3] = $cv[3]; # Conversion Rate
				}
				
				$i ++;
			}
		}
		
		$data = $this->seriesToColumns($newdata);
		if(empty($data)){
			return array();
		}
		foreach($data['fields'] as $key => $val) { 
			$this->columnDefinitions[] = array("Label" => $val);
		}
		$this->setupColumnDefinitions();
		
		# create an empty seed array with the right dimensions
		$ncols = count($data['fields']);
		$nrows = $this->dateNumber($this->from, $this->to, $this->period);
		
		$seed_data = $this->newReportArray($nrows, $ncols);
		
		# merge the actual results with the seed_data array
		foreach ($data['data'] as $key => $val) {			
			$day_id = $this->dateNumber($this->from,strtotime($key), $this->period);
			
			for ($i=0;$i<$ncols;$i++) {
				if (isset($val[$i])) {
					$seed_data[$day_id][$i] = $val[$i];
				}
			}		
		}	
		ksort($seed_data);
		
		return $seed_data;
	}
	
	
	function DisplayReport() {
		global $db;
		
		# get the data from the database
		$data = $this->getReportData();
		
		if($this->displaymode == 'table') {
			$this->Table($data);
		} elseif($this->displaymode == 'areachart') {
			$this->ReportHeader();
			echo "<h2 class='graph_title'>"._VISITORS_TO_TARGET_FILES."</h2>";
			$this->Graph($data, "area", 'page', 0, 300, array(
				"axes" => array(
					"yaxis" => array(
						"showLabel" => true,
						"label" => $this->conversion_mode,
						"rotate" => 90
					)
				)
			));
		} elseif($this->displaymode == 'linechart') {
			$this->ReportHeader();
			echo "<h2 class='graph_title'>"._VISITORS_TO_TARGET_FILES."</h2>";
			$this->Graph($data, "line", 'page', 0, 300, array(
				"axes" => array(
					"yaxis" => array(
						"showLabel" => true,
						"label" => $this->conversion_mode,
						"rotate" => 90
					)
				)
			));
		}
	}
	
	function DisplayCustomForm() {
		echo "<label for='conversion_mode'>Show conversion as</label>";
		echo "<select id='conversion_mode' name='conversion_mode'>";
			if($this->conversion_mode == _CONVERSION_RATE) {
				echo "<option selected value='"._CONVERSION_RATE."'>"._CONVERSION_RATE."</option>";
			} else {
				echo "<option value='"._CONVERSION_RATE."'>"._CONVERSION_RATE."</option>";
			}
			
			if($this->conversion_mode == _CONVERTED_VISITORS) {
				echo "<option selected value='"._CONVERTED_VISITORS."'>"._CONVERTED_VISITORS."</option>";
			} else {
				echo "<option value='"._CONVERTED_VISITORS."'>"._CONVERTED_VISITORS."</option>";
			}
		echo "</select>";
	}
	
	function UpdateStats() {
		return false;		
	}
}
?>